@@ -16,15 +16,15 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 
-from google.api_core.client_options import ClientOptions
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import retry as retries
+from google.api_core.client_options import ClientOptions
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+import pkg_resources
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -33,15 +33,16 @@ except AttributeError:  # pragma: NO COVER
 
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
-from google.cloud.orchestration.airflow.service_v1.services.environments import pagers
-from google.cloud.orchestration.airflow.service_v1.types import environments
-from google.cloud.orchestration.airflow.service_v1.types import operations
 from google.protobuf import empty_pb2  # type: ignore
 from google.protobuf import field_mask_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
-from .transports.base import EnvironmentsTransport, DEFAULT_CLIENT_INFO
-from .transports.grpc_asyncio import EnvironmentsGrpcAsyncIOTransport
+
+from google.cloud.orchestration.airflow.service_v1.services.environments import pagers
+from google.cloud.orchestration.airflow.service_v1.types import environments, operations
+
 from .client import EnvironmentsClient
+from .transports.base import DEFAULT_CLIENT_INFO, EnvironmentsTransport
+from .transports.grpc_asyncio import EnvironmentsGrpcAsyncIOTransport
 
 
 class EnvironmentsAsyncClient:
@@ -220,9 +221,9 @@ class EnvironmentsAsyncClient:
 
             from google.cloud.orchestration.airflow import service_v1
 
-            def sample_create_environment():
+            async def sample_create_environment():
                 # Create a client
-                client = service_v1.EnvironmentsClient()
+                client = service_v1.EnvironmentsAsyncClient()
 
                 # Initialize request argument(s)
                 request = service_v1.CreateEnvironmentRequest(
@@ -233,7 +234,7 @@ class EnvironmentsAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -302,7 +303,12 @@ class EnvironmentsAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -330,16 +336,16 @@ class EnvironmentsAsyncClient:
 
             from google.cloud.orchestration.airflow import service_v1
 
-            def sample_get_environment():
+            async def sample_get_environment():
                 # Create a client
-                client = service_v1.EnvironmentsClient()
+                client = service_v1.EnvironmentsAsyncClient()
 
                 # Initialize request argument(s)
                 request = service_v1.GetEnvironmentRequest(
                 )
 
                 # Make the request
-                response = client.get_environment(request=request)
+                response = await client.get_environment(request=request)
 
                 # Handle the response
                 print(response)
@@ -399,7 +405,12 @@ class EnvironmentsAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -419,9 +430,9 @@ class EnvironmentsAsyncClient:
 
             from google.cloud.orchestration.airflow import service_v1
 
-            def sample_list_environments():
+            async def sample_list_environments():
                 # Create a client
-                client = service_v1.EnvironmentsClient()
+                client = service_v1.EnvironmentsAsyncClient()
 
                 # Initialize request argument(s)
                 request = service_v1.ListEnvironmentsRequest(
@@ -431,7 +442,7 @@ class EnvironmentsAsyncClient:
                 page_result = client.list_environments(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -493,12 +504,20 @@ class EnvironmentsAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListEnvironmentsAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -521,9 +540,9 @@ class EnvironmentsAsyncClient:
 
             from google.cloud.orchestration.airflow import service_v1
 
-            def sample_update_environment():
+            async def sample_update_environment():
                 # Create a client
-                client = service_v1.EnvironmentsClient()
+                client = service_v1.EnvironmentsAsyncClient()
 
                 # Initialize request argument(s)
                 request = service_v1.UpdateEnvironmentRequest(
@@ -534,7 +553,7 @@ class EnvironmentsAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -776,7 +795,12 @@ class EnvironmentsAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -804,9 +828,9 @@ class EnvironmentsAsyncClient:
 
             from google.cloud.orchestration.airflow import service_v1
 
-            def sample_delete_environment():
+            async def sample_delete_environment():
                 # Create a client
-                client = service_v1.EnvironmentsClient()
+                client = service_v1.EnvironmentsAsyncClient()
 
                 # Initialize request argument(s)
                 request = service_v1.DeleteEnvironmentRequest(
@@ -817,7 +841,7 @@ class EnvironmentsAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -854,9 +878,6 @@ class EnvironmentsAsyncClient:
 
                       }
 
-                   The JSON representation for Empty is empty JSON
-                   object {}.
-
         """
         # Create or coerce a protobuf request object.
         # Quick check: If we got a request object, we should *not* have
@@ -890,7 +911,12 @@ class EnvironmentsAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
