@@ -16,18 +16,18 @@
 from collections import OrderedDict
 import os
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
+from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+import pkg_resources
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -36,13 +36,14 @@ except AttributeError:  # pragma: NO COVER
 
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
-from google.cloud.orchestration.airflow.service_v1.services.environments import pagers
-from google.cloud.orchestration.airflow.service_v1.types import environments
-from google.cloud.orchestration.airflow.service_v1.types import operations
 from google.protobuf import empty_pb2  # type: ignore
 from google.protobuf import field_mask_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
-from .transports.base import EnvironmentsTransport, DEFAULT_CLIENT_INFO
+
+from google.cloud.orchestration.airflow.service_v1.services.environments import pagers
+from google.cloud.orchestration.airflow.service_v1.types import environments, operations
+
+from .transports.base import DEFAULT_CLIENT_INFO, EnvironmentsTransport
 from .transports.grpc import EnvironmentsGrpcTransport
 from .transports.grpc_asyncio import EnvironmentsGrpcAsyncIOTransport
 
@@ -59,7 +60,10 @@ class EnvironmentsClientMeta(type):
     _transport_registry["grpc"] = EnvironmentsGrpcTransport
     _transport_registry["grpc_asyncio"] = EnvironmentsGrpcAsyncIOTransport
 
-    def get_transport_class(cls, label: str = None,) -> Type[EnvironmentsTransport]:
+    def get_transport_class(
+        cls,
+        label: str = None,
+    ) -> Type[EnvironmentsTransport]:
         """Returns an appropriate transport class.
 
         Args:
@@ -164,10 +168,18 @@ class EnvironmentsClient(metaclass=EnvironmentsClientMeta):
         return self._transport
 
     @staticmethod
-    def environment_path(project: str, location: str, environment: str,) -> str:
+    def environment_path(
+        project: str,
+        location: str,
+        environment: str,
+    ) -> str:
         """Returns a fully-qualified environment string."""
-        return "projects/{project}/locations/{location}/environments/{environment}".format(
-            project=project, location=location, environment=environment,
+        return (
+            "projects/{project}/locations/{location}/environments/{environment}".format(
+                project=project,
+                location=location,
+                environment=environment,
+            )
         )
 
     @staticmethod
@@ -180,7 +192,9 @@ class EnvironmentsClient(metaclass=EnvironmentsClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_billing_account_path(billing_account: str,) -> str:
+    def common_billing_account_path(
+        billing_account: str,
+    ) -> str:
         """Returns a fully-qualified billing_account string."""
         return "billingAccounts/{billing_account}".format(
             billing_account=billing_account,
@@ -193,9 +207,13 @@ class EnvironmentsClient(metaclass=EnvironmentsClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_folder_path(folder: str,) -> str:
+    def common_folder_path(
+        folder: str,
+    ) -> str:
         """Returns a fully-qualified folder string."""
-        return "folders/{folder}".format(folder=folder,)
+        return "folders/{folder}".format(
+            folder=folder,
+        )
 
     @staticmethod
     def parse_common_folder_path(path: str) -> Dict[str, str]:
@@ -204,9 +222,13 @@ class EnvironmentsClient(metaclass=EnvironmentsClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_organization_path(organization: str,) -> str:
+    def common_organization_path(
+        organization: str,
+    ) -> str:
         """Returns a fully-qualified organization string."""
-        return "organizations/{organization}".format(organization=organization,)
+        return "organizations/{organization}".format(
+            organization=organization,
+        )
 
     @staticmethod
     def parse_common_organization_path(path: str) -> Dict[str, str]:
@@ -215,9 +237,13 @@ class EnvironmentsClient(metaclass=EnvironmentsClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_project_path(project: str,) -> str:
+    def common_project_path(
+        project: str,
+    ) -> str:
         """Returns a fully-qualified project string."""
-        return "projects/{project}".format(project=project,)
+        return "projects/{project}".format(
+            project=project,
+        )
 
     @staticmethod
     def parse_common_project_path(path: str) -> Dict[str, str]:
@@ -226,10 +252,14 @@ class EnvironmentsClient(metaclass=EnvironmentsClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_location_path(project: str, location: str,) -> str:
+    def common_location_path(
+        project: str,
+        location: str,
+    ) -> str:
         """Returns a fully-qualified location string."""
         return "projects/{project}/locations/{location}".format(
-            project=project, location=location,
+            project=project,
+            location=location,
         )
 
     @staticmethod
@@ -401,6 +431,7 @@ class EnvironmentsClient(metaclass=EnvironmentsClientMeta):
                 quota_project_id=client_options.quota_project_id,
                 client_info=client_info,
                 always_use_jwt_access=True,
+                api_audience=client_options.api_audience,
             )
 
     def create_environment(
@@ -501,7 +532,12 @@ class EnvironmentsClient(metaclass=EnvironmentsClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -598,7 +634,12 @@ class EnvironmentsClient(metaclass=EnvironmentsClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -692,12 +733,20 @@ class EnvironmentsClient(metaclass=EnvironmentsClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__iter__` convenience method.
         response = pagers.ListEnvironmentsPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -975,7 +1024,12 @@ class EnvironmentsClient(metaclass=EnvironmentsClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -1053,9 +1107,6 @@ class EnvironmentsClient(metaclass=EnvironmentsClientMeta):
 
                       }
 
-                   The JSON representation for Empty is empty JSON
-                   object {}.
-
         """
         # Create or coerce a protobuf request object.
         # Quick check: If we got a request object, we should *not* have
@@ -1089,7 +1140,12 @@ class EnvironmentsClient(metaclass=EnvironmentsClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
