@@ -13,11 +13,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-import proto  # type: ignore
-
 from google.protobuf import field_mask_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
-
+import proto  # type: ignore
 
 __protobuf__ = proto.module(
     package="google.cloud.orchestration.airflow.service.v1",
@@ -55,8 +53,15 @@ class CreateEnvironmentRequest(proto.Message):
             The environment to create.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    environment = proto.Field(proto.MESSAGE, number=2, message="Environment",)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    environment = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message="Environment",
+    )
 
 
 class GetEnvironmentRequest(proto.Message):
@@ -69,7 +74,10 @@ class GetEnvironmentRequest(proto.Message):
             "projects/{projectId}/locations/{locationId}/environments/{environmentId}".
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class ListEnvironmentsRequest(proto.Message):
@@ -87,9 +95,18 @@ class ListEnvironmentsRequest(proto.Message):
             request, if any.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    page_size = proto.Field(proto.INT32, number=2,)
-    page_token = proto.Field(proto.STRING, number=3,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    page_size = proto.Field(
+        proto.INT32,
+        number=2,
+    )
+    page_token = proto.Field(
+        proto.STRING,
+        number=3,
+    )
 
 
 class ListEnvironmentsResponse(proto.Message):
@@ -108,8 +125,15 @@ class ListEnvironmentsResponse(proto.Message):
     def raw_page(self):
         return self
 
-    environments = proto.RepeatedField(proto.MESSAGE, number=1, message="Environment",)
-    next_page_token = proto.Field(proto.STRING, number=2,)
+    environments = proto.RepeatedField(
+        proto.MESSAGE,
+        number=1,
+        message="Environment",
+    )
+    next_page_token = proto.Field(
+        proto.STRING,
+        number=2,
+    )
 
 
 class DeleteEnvironmentRequest(proto.Message):
@@ -121,7 +145,10 @@ class DeleteEnvironmentRequest(proto.Message):
             "projects/{projectId}/locations/{locationId}/environments/{environmentId}".
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class UpdateEnvironmentRequest(proto.Message):
@@ -290,10 +317,19 @@ class UpdateEnvironmentRequest(proto.Message):
                   variables.
     """
 
-    name = proto.Field(proto.STRING, number=2,)
-    environment = proto.Field(proto.MESSAGE, number=1, message="Environment",)
+    name = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    environment = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message="Environment",
+    )
     update_mask = proto.Field(
-        proto.MESSAGE, number=3, message=field_mask_pb2.FieldMask,
+        proto.MESSAGE,
+        number=3,
+        message=field_mask_pb2.FieldMask,
     )
 
 
@@ -347,25 +383,57 @@ class EnvironmentConfig(proto.Message):
             interface </composer/docs/how-to/accessing/airflow-web-interface>`__).
     """
 
-    gke_cluster = proto.Field(proto.STRING, number=1,)
-    dag_gcs_prefix = proto.Field(proto.STRING, number=2,)
-    node_count = proto.Field(proto.INT32, number=3,)
-    software_config = proto.Field(proto.MESSAGE, number=4, message="SoftwareConfig",)
-    node_config = proto.Field(proto.MESSAGE, number=5, message="NodeConfig",)
+    gke_cluster = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    dag_gcs_prefix = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    node_count = proto.Field(
+        proto.INT32,
+        number=3,
+    )
+    software_config = proto.Field(
+        proto.MESSAGE,
+        number=4,
+        message="SoftwareConfig",
+    )
+    node_config = proto.Field(
+        proto.MESSAGE,
+        number=5,
+        message="NodeConfig",
+    )
     private_environment_config = proto.Field(
-        proto.MESSAGE, number=7, message="PrivateEnvironmentConfig",
+        proto.MESSAGE,
+        number=7,
+        message="PrivateEnvironmentConfig",
     )
     web_server_network_access_control = proto.Field(
-        proto.MESSAGE, number=8, message="WebServerNetworkAccessControl",
+        proto.MESSAGE,
+        number=8,
+        message="WebServerNetworkAccessControl",
+    )
+    database_config = proto.Field(
+        proto.MESSAGE,
+        number=9,
+        message="DatabaseConfig",
     )
-    database_config = proto.Field(proto.MESSAGE, number=9, message="DatabaseConfig",)
     web_server_config = proto.Field(
-        proto.MESSAGE, number=10, message="WebServerConfig",
+        proto.MESSAGE,
+        number=10,
+        message="WebServerConfig",
     )
     encryption_config = proto.Field(
-        proto.MESSAGE, number=11, message="EncryptionConfig",
+        proto.MESSAGE,
+        number=11,
+        message="EncryptionConfig",
+    )
+    airflow_uri = proto.Field(
+        proto.STRING,
+        number=6,
     )
-    airflow_uri = proto.Field(proto.STRING, number=6,)
 
 
 class WebServerNetworkAccessControl(proto.Message):
@@ -397,11 +465,19 @@ class WebServerNetworkAccessControl(proto.Message):
                 contain at most 300 characters.
         """
 
-        value = proto.Field(proto.STRING, number=1,)
-        description = proto.Field(proto.STRING, number=2,)
+        value = proto.Field(
+            proto.STRING,
+            number=1,
+        )
+        description = proto.Field(
+            proto.STRING,
+            number=2,
+        )
 
     allowed_ip_ranges = proto.RepeatedField(
-        proto.MESSAGE, number=1, message=AllowedIpRange,
+        proto.MESSAGE,
+        number=1,
+        message=AllowedIpRange,
     )
 
 
@@ -418,7 +494,10 @@ class DatabaseConfig(proto.Message):
             specified, db-n1-standard-2 will be used.
     """
 
-    machine_type = proto.Field(proto.STRING, number=1,)
+    machine_type = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class WebServerConfig(proto.Message):
@@ -437,7 +516,10 @@ class WebServerConfig(proto.Message):
             manually changed to a non-standard values.
     """
 
-    machine_type = proto.Field(proto.STRING, number=1,)
+    machine_type = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class EncryptionConfig(proto.Message):
@@ -452,7 +534,10 @@ class EncryptionConfig(proto.Message):
             Google-managed key will be used.
     """
 
-    kms_key_name = proto.Field(proto.STRING, number=1,)
+    kms_key_name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class SoftwareConfig(proto.Message):
@@ -484,7 +569,7 @@ class SoftwareConfig(proto.Message):
 
             See also `Version
             List </composer/docs/concepts/versioning/composer-versions>`__.
-        airflow_config_overrides (Sequence[google.cloud.orchestration.airflow.service_v1.types.SoftwareConfig.AirflowConfigOverridesEntry]):
+        airflow_config_overrides (Mapping[str, str]):
             Optional. Apache Airflow configuration properties to
             override.
 
@@ -504,7 +589,7 @@ class SoftwareConfig(proto.Message):
             Certain Apache Airflow configuration property values are
             `blocked </composer/docs/concepts/airflow-configurations>`__,
             and cannot be overridden.
-        pypi_packages (Sequence[google.cloud.orchestration.airflow.service_v1.types.SoftwareConfig.PypiPackagesEntry]):
+        pypi_packages (Mapping[str, str]):
             Optional. Custom Python Package Index (PyPI) packages to be
             installed in the environment.
 
@@ -513,7 +598,7 @@ class SoftwareConfig(proto.Message):
             as "==1.12.0", "[devel,gcp_api]", or "[devel]>=1.8.2,
             <1.9.2". To specify a package without pinning it to a
             version specifier, use the empty string as the value.
-        env_variables (Sequence[google.cloud.orchestration.airflow.service_v1.types.SoftwareConfig.EnvVariablesEntry]):
+        env_variables (Mapping[str, str]):
             Optional. Additional environment variables to provide to the
             Apache Airflow scheduler, worker, and webserver processes.
 
@@ -544,11 +629,29 @@ class SoftwareConfig(proto.Message):
             default is '3'. Cannot be updated.
     """
 
-    image_version = proto.Field(proto.STRING, number=1,)
-    airflow_config_overrides = proto.MapField(proto.STRING, proto.STRING, number=2,)
-    pypi_packages = proto.MapField(proto.STRING, proto.STRING, number=3,)
-    env_variables = proto.MapField(proto.STRING, proto.STRING, number=4,)
-    python_version = proto.Field(proto.STRING, number=6,)
+    image_version = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    airflow_config_overrides = proto.MapField(
+        proto.STRING,
+        proto.STRING,
+        number=2,
+    )
+    pypi_packages = proto.MapField(
+        proto.STRING,
+        proto.STRING,
+        number=3,
+    )
+    env_variables = proto.MapField(
+        proto.STRING,
+        proto.STRING,
+        number=4,
+    )
+    python_version = proto.Field(
+        proto.STRING,
+        number=6,
+    )
 
 
 class IPAllocationPolicy(proto.Message):
@@ -624,18 +727,29 @@ class IPAllocationPolicy(proto.Message):
             This field is a member of `oneof`_ ``services_ip_allocation``.
     """
 
-    use_ip_aliases = proto.Field(proto.BOOL, number=1,)
+    use_ip_aliases = proto.Field(
+        proto.BOOL,
+        number=1,
+    )
     cluster_secondary_range_name = proto.Field(
-        proto.STRING, number=2, oneof="cluster_ip_allocation",
+        proto.STRING,
+        number=2,
+        oneof="cluster_ip_allocation",
     )
     cluster_ipv4_cidr_block = proto.Field(
-        proto.STRING, number=4, oneof="cluster_ip_allocation",
+        proto.STRING,
+        number=4,
+        oneof="cluster_ip_allocation",
     )
     services_secondary_range_name = proto.Field(
-        proto.STRING, number=3, oneof="services_ip_allocation",
+        proto.STRING,
+        number=3,
+        oneof="services_ip_allocation",
     )
     services_ipv4_cidr_block = proto.Field(
-        proto.STRING, number=5, oneof="services_ip_allocation",
+        proto.STRING,
+        number=5,
+        oneof="services_ip_allocation",
     )
 
 
@@ -735,16 +849,42 @@ class NodeConfig(proto.Message):
             how IPs are allocated in the GKE cluster.
     """
 
-    location = proto.Field(proto.STRING, number=1,)
-    machine_type = proto.Field(proto.STRING, number=2,)
-    network = proto.Field(proto.STRING, number=3,)
-    subnetwork = proto.Field(proto.STRING, number=4,)
-    disk_size_gb = proto.Field(proto.INT32, number=5,)
-    oauth_scopes = proto.RepeatedField(proto.STRING, number=6,)
-    service_account = proto.Field(proto.STRING, number=7,)
-    tags = proto.RepeatedField(proto.STRING, number=8,)
+    location = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    machine_type = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    network = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    subnetwork = proto.Field(
+        proto.STRING,
+        number=4,
+    )
+    disk_size_gb = proto.Field(
+        proto.INT32,
+        number=5,
+    )
+    oauth_scopes = proto.RepeatedField(
+        proto.STRING,
+        number=6,
+    )
+    service_account = proto.Field(
+        proto.STRING,
+        number=7,
+    )
+    tags = proto.RepeatedField(
+        proto.STRING,
+        number=8,
+    )
     ip_allocation_policy = proto.Field(
-        proto.MESSAGE, number=9, message="IPAllocationPolicy",
+        proto.MESSAGE,
+        number=9,
+        message="IPAllocationPolicy",
     )
 
 
@@ -771,9 +911,18 @@ class PrivateClusterConfig(proto.Message):
             within the cluster's network.
     """
 
-    enable_private_endpoint = proto.Field(proto.BOOL, number=1,)
-    master_ipv4_cidr_block = proto.Field(proto.STRING, number=2,)
-    master_ipv4_reserved_range = proto.Field(proto.STRING, number=3,)
+    enable_private_endpoint = proto.Field(
+        proto.BOOL,
+        number=1,
+    )
+    master_ipv4_cidr_block = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    master_ipv4_reserved_range = proto.Field(
+        proto.STRING,
+        number=3,
+    )
 
 
 class PrivateEnvironmentConfig(proto.Message):
@@ -803,13 +952,27 @@ class PrivateEnvironmentConfig(proto.Message):
             tenant project's App Engine VMs.
     """
 
-    enable_private_environment = proto.Field(proto.BOOL, number=1,)
+    enable_private_environment = proto.Field(
+        proto.BOOL,
+        number=1,
+    )
     private_cluster_config = proto.Field(
-        proto.MESSAGE, number=2, message="PrivateClusterConfig",
+        proto.MESSAGE,
+        number=2,
+        message="PrivateClusterConfig",
+    )
+    web_server_ipv4_cidr_block = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    cloud_sql_ipv4_cidr_block = proto.Field(
+        proto.STRING,
+        number=4,
+    )
+    web_server_ipv4_reserved_range = proto.Field(
+        proto.STRING,
+        number=5,
     )
-    web_server_ipv4_cidr_block = proto.Field(proto.STRING, number=3,)
-    cloud_sql_ipv4_cidr_block = proto.Field(proto.STRING, number=4,)
-    web_server_ipv4_reserved_range = proto.Field(proto.STRING, number=5,)
 
 
 class Environment(proto.Message):
@@ -839,7 +1002,7 @@ class Environment(proto.Message):
         update_time (google.protobuf.timestamp_pb2.Timestamp):
             Output only. The time at which this
             environment was last modified.
-        labels (Sequence[google.cloud.orchestration.airflow.service_v1.types.Environment.LabelsEntry]):
+        labels (Mapping[str, str]):
             Optional. User-defined labels for this environment. The
             labels map can contain no more than 64 entries. Entries of
             the labels map are UTF8 strings that comply with the
@@ -862,13 +1025,39 @@ class Environment(proto.Message):
         DELETING = 4
         ERROR = 5
 
-    name = proto.Field(proto.STRING, number=1,)
-    config = proto.Field(proto.MESSAGE, number=2, message="EnvironmentConfig",)
-    uuid = proto.Field(proto.STRING, number=3,)
-    state = proto.Field(proto.ENUM, number=4, enum=State,)
-    create_time = proto.Field(proto.MESSAGE, number=5, message=timestamp_pb2.Timestamp,)
-    update_time = proto.Field(proto.MESSAGE, number=6, message=timestamp_pb2.Timestamp,)
-    labels = proto.MapField(proto.STRING, proto.STRING, number=7,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    config = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message="EnvironmentConfig",
+    )
+    uuid = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    state = proto.Field(
+        proto.ENUM,
+        number=4,
+        enum=State,
+    )
+    create_time = proto.Field(
+        proto.MESSAGE,
+        number=5,
+        message=timestamp_pb2.Timestamp,
+    )
+    update_time = proto.Field(
+        proto.MESSAGE,
+        number=6,
+        message=timestamp_pb2.Timestamp,
+    )
+    labels = proto.MapField(
+        proto.STRING,
+        proto.STRING,
+        number=7,
+    )
 
 
 class CheckUpgradeResponse(proto.Message):
@@ -889,7 +1078,7 @@ class CheckUpgradeResponse(proto.Message):
         image_version (str):
             Composer image for which the build was
             happening.
-        pypi_dependencies (Sequence[google.cloud.orchestration.airflow.service_v1.types.CheckUpgradeResponse.PypiDependenciesEntry]):
+        pypi_dependencies (Mapping[str, str]):
             Pypi dependencies specified in the
             environment configuration, at the time when the
             build was triggered.
@@ -903,13 +1092,28 @@ class CheckUpgradeResponse(proto.Message):
         CONFLICT = 1
         NO_CONFLICT = 2
 
-    build_log_uri = proto.Field(proto.STRING, number=1,)
+    build_log_uri = proto.Field(
+        proto.STRING,
+        number=1,
+    )
     contains_pypi_modules_conflict = proto.Field(
-        proto.ENUM, number=4, enum=ConflictResult,
+        proto.ENUM,
+        number=4,
+        enum=ConflictResult,
+    )
+    pypi_conflict_build_log_extract = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    image_version = proto.Field(
+        proto.STRING,
+        number=5,
+    )
+    pypi_dependencies = proto.MapField(
+        proto.STRING,
+        proto.STRING,
+        number=6,
     )
-    pypi_conflict_build_log_extract = proto.Field(proto.STRING, number=3,)
-    image_version = proto.Field(proto.STRING, number=5,)
-    pypi_dependencies = proto.MapField(proto.STRING, proto.STRING, number=6,)
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
