@@ -16,15 +16,15 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 
-from google.api_core.client_options import ClientOptions
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import retry as retries
+from google.api_core.client_options import ClientOptions
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+import pkg_resources
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -33,17 +33,21 @@ except AttributeError:  # pragma: NO COVER
 
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
-from google.cloud.orchestration.airflow.service_v1beta1.services.environments import (
-    pagers,
-)
-from google.cloud.orchestration.airflow.service_v1beta1.types import environments
-from google.cloud.orchestration.airflow.service_v1beta1.types import operations
 from google.protobuf import empty_pb2  # type: ignore
 from google.protobuf import field_mask_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
-from .transports.base import EnvironmentsTransport, DEFAULT_CLIENT_INFO
-from .transports.grpc_asyncio import EnvironmentsGrpcAsyncIOTransport
+
+from google.cloud.orchestration.airflow.service_v1beta1.services.environments import (
+    pagers,
+)
+from google.cloud.orchestration.airflow.service_v1beta1.types import (
+    environments,
+    operations,
+)
+
 from .client import EnvironmentsClient
+from .transports.base import DEFAULT_CLIENT_INFO, EnvironmentsTransport
+from .transports.grpc_asyncio import EnvironmentsGrpcAsyncIOTransport
 
 
 class EnvironmentsAsyncClient:
@@ -222,9 +226,9 @@ class EnvironmentsAsyncClient:
 
             from google.cloud.orchestration.airflow import service_v1beta1
 
-            def sample_create_environment():
+            async def sample_create_environment():
                 # Create a client
-                client = service_v1beta1.EnvironmentsClient()
+                client = service_v1beta1.EnvironmentsAsyncClient()
 
                 # Initialize request argument(s)
                 request = service_v1beta1.CreateEnvironmentRequest(
@@ -235,7 +239,7 @@ class EnvironmentsAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -304,7 +308,12 @@ class EnvironmentsAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -332,16 +341,16 @@ class EnvironmentsAsyncClient:
 
             from google.cloud.orchestration.airflow import service_v1beta1
 
-            def sample_get_environment():
+            async def sample_get_environment():
                 # Create a client
-                client = service_v1beta1.EnvironmentsClient()
+                client = service_v1beta1.EnvironmentsAsyncClient()
 
                 # Initialize request argument(s)
                 request = service_v1beta1.GetEnvironmentRequest(
                 )
 
                 # Make the request
-                response = client.get_environment(request=request)
+                response = await client.get_environment(request=request)
 
                 # Handle the response
                 print(response)
@@ -401,7 +410,12 @@ class EnvironmentsAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -421,9 +435,9 @@ class EnvironmentsAsyncClient:
 
             from google.cloud.orchestration.airflow import service_v1beta1
 
-            def sample_list_environments():
+            async def sample_list_environments():
                 # Create a client
-                client = service_v1beta1.EnvironmentsClient()
+                client = service_v1beta1.EnvironmentsAsyncClient()
 
                 # Initialize request argument(s)
                 request = service_v1beta1.ListEnvironmentsRequest(
@@ -433,7 +447,7 @@ class EnvironmentsAsyncClient:
                 page_result = client.list_environments(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -495,12 +509,20 @@ class EnvironmentsAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListEnvironmentsAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -523,9 +545,9 @@ class EnvironmentsAsyncClient:
 
             from google.cloud.orchestration.airflow import service_v1beta1
 
-            def sample_update_environment():
+            async def sample_update_environment():
                 # Create a client
-                client = service_v1beta1.EnvironmentsClient()
+                client = service_v1beta1.EnvironmentsAsyncClient()
 
                 # Initialize request argument(s)
                 request = service_v1beta1.UpdateEnvironmentRequest(
@@ -536,7 +558,7 @@ class EnvironmentsAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -798,7 +820,12 @@ class EnvironmentsAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -826,9 +853,9 @@ class EnvironmentsAsyncClient:
 
             from google.cloud.orchestration.airflow import service_v1beta1
 
-            def sample_delete_environment():
+            async def sample_delete_environment():
                 # Create a client
-                client = service_v1beta1.EnvironmentsClient()
+                client = service_v1beta1.EnvironmentsAsyncClient()
 
                 # Initialize request argument(s)
                 request = service_v1beta1.DeleteEnvironmentRequest(
@@ -839,7 +866,7 @@ class EnvironmentsAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -876,9 +903,6 @@ class EnvironmentsAsyncClient:
 
                       }
 
-                   The JSON representation for Empty is empty JSON
-                   object {}.
-
         """
         # Create or coerce a protobuf request object.
         # Quick check: If we got a request object, we should *not* have
@@ -912,7 +936,12 @@ class EnvironmentsAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -939,9 +968,9 @@ class EnvironmentsAsyncClient:
 
             from google.cloud.orchestration.airflow import service_v1beta1
 
-            def sample_restart_web_server():
+            async def sample_restart_web_server():
                 # Create a client
-                client = service_v1beta1.EnvironmentsClient()
+                client = service_v1beta1.EnvironmentsAsyncClient()
 
                 # Initialize request argument(s)
                 request = service_v1beta1.RestartWebServerRequest(
@@ -952,7 +981,7 @@ class EnvironmentsAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -993,7 +1022,12 @@ class EnvironmentsAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -1019,14 +1053,13 @@ class EnvironmentsAsyncClient:
         In case of problems detailed info can be found in the
         returned Operation.
 
-
         .. code-block:: python
 
             from google.cloud.orchestration.airflow import service_v1beta1
 
-            def sample_check_upgrade():
+            async def sample_check_upgrade():
                 # Create a client
-                client = service_v1beta1.EnvironmentsClient()
+                client = service_v1beta1.EnvironmentsAsyncClient()
 
                 # Initialize request argument(s)
                 request = service_v1beta1.CheckUpgradeRequest(
@@ -1037,7 +1070,7 @@ class EnvironmentsAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -1080,7 +1113,12 @@ class EnvironmentsAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
