@@ -14,36 +14,35 @@
 # limitations under the License.
 #
 import os
-import mock
 
-import grpc
-from grpc.experimental import aio
+# try/except added for compatibility with python < 3.8
+try:
+    from unittest import mock
+    from unittest.mock import AsyncMock
+except ImportError:
+    import mock
+
 import math
-import pytest
-from proto.marshal.rules.dates import DurationRule, TimestampRule
-
 
+from google.api_core import gapic_v1, grpc_helpers, grpc_helpers_async, path_template
 from google.api_core import client_options
 from google.api_core import exceptions as core_exceptions
-from google.api_core import gapic_v1
-from google.api_core import grpc_helpers
-from google.api_core import grpc_helpers_async
-from google.api_core import path_template
+import google.auth
 from google.auth import credentials as ga_credentials
 from google.auth.exceptions import MutualTLSChannelError
+from google.oauth2 import service_account
+import grpc
+from grpc.experimental import aio
+from proto.marshal.rules.dates import DurationRule, TimestampRule
+import pytest
+
 from google.cloud.orchestration.airflow.service_v1.services.image_versions import (
     ImageVersionsAsyncClient,
-)
-from google.cloud.orchestration.airflow.service_v1.services.image_versions import (
     ImageVersionsClient,
-)
-from google.cloud.orchestration.airflow.service_v1.services.image_versions import pagers
-from google.cloud.orchestration.airflow.service_v1.services.image_versions import (
+    pagers,
     transports,
 )
 from google.cloud.orchestration.airflow.service_v1.types import image_versions
-from google.oauth2 import service_account
-import google.auth
 
 
 def client_cert_source_callback():
@@ -91,20 +90,24 @@ def test__get_default_mtls_endpoint():
 
 
 @pytest.mark.parametrize(
-    "client_class", [ImageVersionsClient, ImageVersionsAsyncClient,]
+    "client_class,transport_name",
+    [
+        (ImageVersionsClient, "grpc"),
+        (ImageVersionsAsyncClient, "grpc_asyncio"),
+    ],
 )
-def test_image_versions_client_from_service_account_info(client_class):
+def test_image_versions_client_from_service_account_info(client_class, transport_name):
     creds = ga_credentials.AnonymousCredentials()
     with mock.patch.object(
         service_account.Credentials, "from_service_account_info"
     ) as factory:
         factory.return_value = creds
         info = {"valid": True}
-        client = client_class.from_service_account_info(info)
+        client = client_class.from_service_account_info(info, transport=transport_name)
         assert client.transport._credentials == creds
         assert isinstance(client, client_class)
 
-        assert client.transport._host == "composer.googleapis.com:443"
+        assert client.transport._host == ("composer.googleapis.com:443")
 
 
 @pytest.mark.parametrize(
@@ -133,23 +136,31 @@ def test_image_versions_client_service_account_always_use_jwt(
 
 
 @pytest.mark.parametrize(
-    "client_class", [ImageVersionsClient, ImageVersionsAsyncClient,]
+    "client_class,transport_name",
+    [
+        (ImageVersionsClient, "grpc"),
+        (ImageVersionsAsyncClient, "grpc_asyncio"),
+    ],
 )
-def test_image_versions_client_from_service_account_file(client_class):
+def test_image_versions_client_from_service_account_file(client_class, transport_name):
     creds = ga_credentials.AnonymousCredentials()
     with mock.patch.object(
         service_account.Credentials, "from_service_account_file"
     ) as factory:
         factory.return_value = creds
-        client = client_class.from_service_account_file("dummy/file/path.json")
+        client = client_class.from_service_account_file(
+            "dummy/file/path.json", transport=transport_name
+        )
         assert client.transport._credentials == creds
         assert isinstance(client, client_class)
 
-        client = client_class.from_service_account_json("dummy/file/path.json")
+        client = client_class.from_service_account_json(
+            "dummy/file/path.json", transport=transport_name
+        )
         assert client.transport._credentials == creds
         assert isinstance(client, client_class)
 
-        assert client.transport._host == "composer.googleapis.com:443"
+        assert client.transport._host == ("composer.googleapis.com:443")
 
 
 def test_image_versions_client_get_transport_class():
@@ -212,6 +223,7 @@ def test_image_versions_client_client_options(
             quota_project_id=None,
             client_info=transports.base.DEFAULT_CLIENT_INFO,
             always_use_jwt_access=True,
+            api_audience=None,
         )
 
     # Check the case api_endpoint is not provided and GOOGLE_API_USE_MTLS_ENDPOINT is
@@ -229,6 +241,7 @@ def test_image_versions_client_client_options(
                 quota_project_id=None,
                 client_info=transports.base.DEFAULT_CLIENT_INFO,
                 always_use_jwt_access=True,
+                api_audience=None,
             )
 
     # Check the case api_endpoint is not provided and GOOGLE_API_USE_MTLS_ENDPOINT is
@@ -246,6 +259,7 @@ def test_image_versions_client_client_options(
                 quota_project_id=None,
                 client_info=transports.base.DEFAULT_CLIENT_INFO,
                 always_use_jwt_access=True,
+                api_audience=None,
             )
 
     # Check the case api_endpoint is not provided and GOOGLE_API_USE_MTLS_ENDPOINT has
@@ -275,6 +289,25 @@ def test_image_versions_client_client_options(
             quota_project_id="octopus",
             client_info=transports.base.DEFAULT_CLIENT_INFO,
             always_use_jwt_access=True,
+            api_audience=None,
+        )
+    # Check the case api_endpoint is provided
+    options = client_options.ClientOptions(
+        api_audience="https://language.googleapis.com"
+    )
+    with mock.patch.object(transport_class, "__init__") as patched:
+        patched.return_value = None
+        client = client_class(client_options=options, transport=transport_name)
+        patched.assert_called_once_with(
+            credentials=None,
+            credentials_file=None,
+            host=client.DEFAULT_ENDPOINT,
+            scopes=None,
+            client_cert_source_for_mtls=None,
+            quota_project_id=None,
+            client_info=transports.base.DEFAULT_CLIENT_INFO,
+            always_use_jwt_access=True,
+            api_audience="https://language.googleapis.com",
         )
 
 
@@ -342,6 +375,7 @@ def test_image_versions_client_mtls_env_auto(
                 quota_project_id=None,
                 client_info=transports.base.DEFAULT_CLIENT_INFO,
                 always_use_jwt_access=True,
+                api_audience=None,
             )
 
     # Check the case ADC client cert is provided. Whether client cert is used depends on
@@ -376,6 +410,7 @@ def test_image_versions_client_mtls_env_auto(
                         quota_project_id=None,
                         client_info=transports.base.DEFAULT_CLIENT_INFO,
                         always_use_jwt_access=True,
+                        api_audience=None,
                     )
 
     # Check the case client_cert_source and ADC client cert are not provided.
@@ -398,6 +433,7 @@ def test_image_versions_client_mtls_env_auto(
                     quota_project_id=None,
                     client_info=transports.base.DEFAULT_CLIENT_INFO,
                     always_use_jwt_access=True,
+                    api_audience=None,
                 )
 
 
@@ -497,7 +533,9 @@ def test_image_versions_client_client_options_scopes(
     client_class, transport_class, transport_name
 ):
     # Check the case scopes are provided.
-    options = client_options.ClientOptions(scopes=["1", "2"],)
+    options = client_options.ClientOptions(
+        scopes=["1", "2"],
+    )
     with mock.patch.object(transport_class, "__init__") as patched:
         patched.return_value = None
         client = client_class(client_options=options, transport=transport_name)
@@ -510,6 +548,7 @@ def test_image_versions_client_client_options_scopes(
             quota_project_id=None,
             client_info=transports.base.DEFAULT_CLIENT_INFO,
             always_use_jwt_access=True,
+            api_audience=None,
         )
 
 
@@ -548,6 +587,7 @@ def test_image_versions_client_client_options_credentials_file(
             quota_project_id=None,
             client_info=transports.base.DEFAULT_CLIENT_INFO,
             always_use_jwt_access=True,
+            api_audience=None,
         )
 
 
@@ -568,6 +608,7 @@ def test_image_versions_client_client_options_from_dict():
             quota_project_id=None,
             client_info=transports.base.DEFAULT_CLIENT_INFO,
             always_use_jwt_access=True,
+            api_audience=None,
         )
 
 
@@ -606,6 +647,7 @@ def test_image_versions_client_create_channel_credentials_file(
             quota_project_id=None,
             client_info=transports.base.DEFAULT_CLIENT_INFO,
             always_use_jwt_access=True,
+            api_audience=None,
         )
 
     # test that the credentials from file are saved and used as the credentials.
@@ -638,11 +680,16 @@ def test_image_versions_client_create_channel_credentials_file(
 
 
 @pytest.mark.parametrize(
-    "request_type", [image_versions.ListImageVersionsRequest, dict,]
+    "request_type",
+    [
+        image_versions.ListImageVersionsRequest,
+        dict,
+    ],
 )
 def test_list_image_versions(request_type, transport: str = "grpc"):
     client = ImageVersionsClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -673,7 +720,8 @@ def test_list_image_versions_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
     client = ImageVersionsClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc",
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -692,7 +740,8 @@ async def test_list_image_versions_async(
     request_type=image_versions.ListImageVersionsRequest,
 ):
     client = ImageVersionsAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -727,13 +776,15 @@ async def test_list_image_versions_async_from_dict():
 
 
 def test_list_image_versions_field_headers():
-    client = ImageVersionsClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = ImageVersionsClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Any value that is part of the HTTP/1.1 URI should be sent as
     # a field header. Set these to a non-empty value.
     request = image_versions.ListImageVersionsRequest()
 
-    request.parent = "parent/value"
+    request.parent = "parent_value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
@@ -749,7 +800,10 @@ def test_list_image_versions_field_headers():
 
     # Establish that the field header was sent.
     _, _, kw = call.mock_calls[0]
-    assert ("x-goog-request-params", "parent=parent/value",) in kw["metadata"]
+    assert (
+        "x-goog-request-params",
+        "parent=parent_value",
+    ) in kw["metadata"]
 
 
 @pytest.mark.asyncio
@@ -762,7 +816,7 @@ async def test_list_image_versions_field_headers_async():
     # a field header. Set these to a non-empty value.
     request = image_versions.ListImageVersionsRequest()
 
-    request.parent = "parent/value"
+    request.parent = "parent_value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
@@ -780,11 +834,16 @@ async def test_list_image_versions_field_headers_async():
 
     # Establish that the field header was sent.
     _, _, kw = call.mock_calls[0]
-    assert ("x-goog-request-params", "parent=parent/value",) in kw["metadata"]
+    assert (
+        "x-goog-request-params",
+        "parent=parent_value",
+    ) in kw["metadata"]
 
 
 def test_list_image_versions_flattened():
-    client = ImageVersionsClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = ImageVersionsClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
@@ -794,7 +853,9 @@ def test_list_image_versions_flattened():
         call.return_value = image_versions.ListImageVersionsResponse()
         # Call the method with a truthy value for each flattened field,
         # using the keyword arguments to the method.
-        client.list_image_versions(parent="parent_value",)
+        client.list_image_versions(
+            parent="parent_value",
+        )
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -806,13 +867,16 @@ def test_list_image_versions_flattened():
 
 
 def test_list_image_versions_flattened_error():
-    client = ImageVersionsClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = ImageVersionsClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
         client.list_image_versions(
-            image_versions.ListImageVersionsRequest(), parent="parent_value",
+            image_versions.ListImageVersionsRequest(),
+            parent="parent_value",
         )
 
 
@@ -834,7 +898,9 @@ async def test_list_image_versions_flattened_async():
         )
         # Call the method with a truthy value for each flattened field,
         # using the keyword arguments to the method.
-        response = await client.list_image_versions(parent="parent_value",)
+        response = await client.list_image_versions(
+            parent="parent_value",
+        )
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -855,13 +921,15 @@ async def test_list_image_versions_flattened_error_async():
     # fields is an error.
     with pytest.raises(ValueError):
         await client.list_image_versions(
-            image_versions.ListImageVersionsRequest(), parent="parent_value",
+            image_versions.ListImageVersionsRequest(),
+            parent="parent_value",
         )
 
 
 def test_list_image_versions_pager(transport_name: str = "grpc"):
     client = ImageVersionsClient(
-        credentials=ga_credentials.AnonymousCredentials, transport=transport_name,
+        credentials=ga_credentials.AnonymousCredentials,
+        transport=transport_name,
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -879,10 +947,14 @@ def test_list_image_versions_pager(transport_name: str = "grpc"):
                 next_page_token="abc",
             ),
             image_versions.ListImageVersionsResponse(
-                image_versions=[], next_page_token="def",
+                image_versions=[],
+                next_page_token="def",
             ),
             image_versions.ListImageVersionsResponse(
-                image_versions=[image_versions.ImageVersion(),], next_page_token="ghi",
+                image_versions=[
+                    image_versions.ImageVersion(),
+                ],
+                next_page_token="ghi",
             ),
             image_versions.ListImageVersionsResponse(
                 image_versions=[
@@ -901,14 +973,15 @@ def test_list_image_versions_pager(transport_name: str = "grpc"):
 
         assert pager._metadata == metadata
 
-        results = [i for i in pager]
+        results = list(pager)
         assert len(results) == 6
         assert all(isinstance(i, image_versions.ImageVersion) for i in results)
 
 
 def test_list_image_versions_pages(transport_name: str = "grpc"):
     client = ImageVersionsClient(
-        credentials=ga_credentials.AnonymousCredentials, transport=transport_name,
+        credentials=ga_credentials.AnonymousCredentials,
+        transport=transport_name,
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -926,10 +999,14 @@ def test_list_image_versions_pages(transport_name: str = "grpc"):
                 next_page_token="abc",
             ),
             image_versions.ListImageVersionsResponse(
-                image_versions=[], next_page_token="def",
+                image_versions=[],
+                next_page_token="def",
             ),
             image_versions.ListImageVersionsResponse(
-                image_versions=[image_versions.ImageVersion(),], next_page_token="ghi",
+                image_versions=[
+                    image_versions.ImageVersion(),
+                ],
+                next_page_token="ghi",
             ),
             image_versions.ListImageVersionsResponse(
                 image_versions=[
@@ -946,7 +1023,9 @@ def test_list_image_versions_pages(transport_name: str = "grpc"):
 
 @pytest.mark.asyncio
 async def test_list_image_versions_async_pager():
-    client = ImageVersionsAsyncClient(credentials=ga_credentials.AnonymousCredentials,)
+    client = ImageVersionsAsyncClient(
+        credentials=ga_credentials.AnonymousCredentials,
+    )
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
@@ -965,10 +1044,14 @@ async def test_list_image_versions_async_pager():
                 next_page_token="abc",
             ),
             image_versions.ListImageVersionsResponse(
-                image_versions=[], next_page_token="def",
+                image_versions=[],
+                next_page_token="def",
             ),
             image_versions.ListImageVersionsResponse(
-                image_versions=[image_versions.ImageVersion(),], next_page_token="ghi",
+                image_versions=[
+                    image_versions.ImageVersion(),
+                ],
+                next_page_token="ghi",
             ),
             image_versions.ListImageVersionsResponse(
                 image_versions=[
@@ -978,10 +1061,12 @@ async def test_list_image_versions_async_pager():
             ),
             RuntimeError,
         )
-        async_pager = await client.list_image_versions(request={},)
+        async_pager = await client.list_image_versions(
+            request={},
+        )
         assert async_pager.next_page_token == "abc"
         responses = []
-        async for response in async_pager:
+        async for response in async_pager:  # pragma: no branch
             responses.append(response)
 
         assert len(responses) == 6
@@ -990,7 +1075,9 @@ async def test_list_image_versions_async_pager():
 
 @pytest.mark.asyncio
 async def test_list_image_versions_async_pages():
-    client = ImageVersionsAsyncClient(credentials=ga_credentials.AnonymousCredentials,)
+    client = ImageVersionsAsyncClient(
+        credentials=ga_credentials.AnonymousCredentials,
+    )
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
@@ -1009,10 +1096,14 @@ async def test_list_image_versions_async_pages():
                 next_page_token="abc",
             ),
             image_versions.ListImageVersionsResponse(
-                image_versions=[], next_page_token="def",
+                image_versions=[],
+                next_page_token="def",
             ),
             image_versions.ListImageVersionsResponse(
-                image_versions=[image_versions.ImageVersion(),], next_page_token="ghi",
+                image_versions=[
+                    image_versions.ImageVersion(),
+                ],
+                next_page_token="ghi",
             ),
             image_versions.ListImageVersionsResponse(
                 image_versions=[
@@ -1023,7 +1114,9 @@ async def test_list_image_versions_async_pages():
             RuntimeError,
         )
         pages = []
-        async for page_ in (await client.list_image_versions(request={})).pages:
+        async for page_ in (
+            await client.list_image_versions(request={})
+        ).pages:  # pragma: no branch
             pages.append(page_)
         for page_, token in zip(pages, ["abc", "def", "ghi", ""]):
             assert page_.raw_page.next_page_token == token
@@ -1036,7 +1129,8 @@ def test_credentials_transport_error():
     )
     with pytest.raises(ValueError):
         client = ImageVersionsClient(
-            credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+            credentials=ga_credentials.AnonymousCredentials(),
+            transport=transport,
         )
 
     # It is an error to provide a credentials file and a transport instance.
@@ -1056,7 +1150,10 @@ def test_credentials_transport_error():
     options = client_options.ClientOptions()
     options.api_key = "api_key"
     with pytest.raises(ValueError):
-        client = ImageVersionsClient(client_options=options, transport=transport,)
+        client = ImageVersionsClient(
+            client_options=options,
+            transport=transport,
+        )
 
     # It is an error to provide an api_key and a credential.
     options = mock.Mock()
@@ -1072,7 +1169,8 @@ def test_credentials_transport_error():
     )
     with pytest.raises(ValueError):
         client = ImageVersionsClient(
-            client_options={"scopes": ["1", "2"]}, transport=transport,
+            client_options={"scopes": ["1", "2"]},
+            transport=transport,
         )
 
 
@@ -1115,10 +1213,28 @@ def test_transport_adc(transport_class):
         adc.assert_called_once()
 
 
+@pytest.mark.parametrize(
+    "transport_name",
+    [
+        "grpc",
+    ],
+)
+def test_transport_kind(transport_name):
+    transport = ImageVersionsClient.get_transport_class(transport_name)(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
+    assert transport.kind == transport_name
+
+
 def test_transport_grpc_default():
     # A client should use the gRPC transport by default.
-    client = ImageVersionsClient(credentials=ga_credentials.AnonymousCredentials(),)
-    assert isinstance(client.transport, transports.ImageVersionsGrpcTransport,)
+    client = ImageVersionsClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
+    assert isinstance(
+        client.transport,
+        transports.ImageVersionsGrpcTransport,
+    )
 
 
 def test_image_versions_base_transport_error():
@@ -1150,6 +1266,14 @@ def test_image_versions_base_transport():
     with pytest.raises(NotImplementedError):
         transport.close()
 
+    # Catch all for all remaining methods and properties
+    remainder = [
+        "kind",
+    ]
+    for r in remainder:
+        with pytest.raises(NotImplementedError):
+            getattr(transport, r)()
+
 
 def test_image_versions_base_transport_with_credentials_file():
     # Instantiate the base transport with a credentials file
@@ -1161,7 +1285,8 @@ def test_image_versions_base_transport_with_credentials_file():
         Transport.return_value = None
         load_creds.return_value = (ga_credentials.AnonymousCredentials(), None)
         transport = transports.ImageVersionsTransport(
-            credentials_file="credentials.json", quota_project_id="octopus",
+            credentials_file="credentials.json",
+            quota_project_id="octopus",
         )
         load_creds.assert_called_once_with(
             "credentials.json",
@@ -1214,6 +1339,28 @@ def test_image_versions_transport_auth_adc(transport_class):
         )
 
 
+@pytest.mark.parametrize(
+    "transport_class",
+    [
+        transports.ImageVersionsGrpcTransport,
+        transports.ImageVersionsGrpcAsyncIOTransport,
+    ],
+)
+def test_image_versions_transport_auth_gdch_credentials(transport_class):
+    host = "https://language.com"
+    api_audience_tests = [None, "https://language2.com"]
+    api_audience_expect = [host, "https://language2.com"]
+    for t, e in zip(api_audience_tests, api_audience_expect):
+        with mock.patch.object(google.auth, "default", autospec=True) as adc:
+            gdch_mock = mock.MagicMock()
+            type(gdch_mock).with_gdch_audience = mock.PropertyMock(
+                return_value=gdch_mock
+            )
+            adc.return_value = (gdch_mock, None)
+            transport_class(host=host, api_audience=t)
+            gdch_mock.with_gdch_audience.assert_called_once_with(e)
+
+
 @pytest.mark.parametrize(
     "transport_class,grpc_helpers",
     [
@@ -1294,24 +1441,40 @@ def test_image_versions_grpc_transport_client_cert_source_for_mtls(transport_cla
             )
 
 
-def test_image_versions_host_no_port():
+@pytest.mark.parametrize(
+    "transport_name",
+    [
+        "grpc",
+        "grpc_asyncio",
+    ],
+)
+def test_image_versions_host_no_port(transport_name):
     client = ImageVersionsClient(
         credentials=ga_credentials.AnonymousCredentials(),
         client_options=client_options.ClientOptions(
             api_endpoint="composer.googleapis.com"
         ),
+        transport=transport_name,
     )
-    assert client.transport._host == "composer.googleapis.com:443"
+    assert client.transport._host == ("composer.googleapis.com:443")
 
 
-def test_image_versions_host_with_port():
+@pytest.mark.parametrize(
+    "transport_name",
+    [
+        "grpc",
+        "grpc_asyncio",
+    ],
+)
+def test_image_versions_host_with_port(transport_name):
     client = ImageVersionsClient(
         credentials=ga_credentials.AnonymousCredentials(),
         client_options=client_options.ClientOptions(
             api_endpoint="composer.googleapis.com:8000"
         ),
+        transport=transport_name,
     )
-    assert client.transport._host == "composer.googleapis.com:8000"
+    assert client.transport._host == ("composer.googleapis.com:8000")
 
 
 def test_image_versions_grpc_transport_channel():
@@ -1319,7 +1482,8 @@ def test_image_versions_grpc_transport_channel():
 
     # Check that channel is used if provided.
     transport = transports.ImageVersionsGrpcTransport(
-        host="squid.clam.whelk", channel=channel,
+        host="squid.clam.whelk",
+        channel=channel,
     )
     assert transport.grpc_channel == channel
     assert transport._host == "squid.clam.whelk:443"
@@ -1331,7 +1495,8 @@ def test_image_versions_grpc_asyncio_transport_channel():
 
     # Check that channel is used if provided.
     transport = transports.ImageVersionsGrpcAsyncIOTransport(
-        host="squid.clam.whelk", channel=channel,
+        host="squid.clam.whelk",
+        channel=channel,
     )
     assert transport.grpc_channel == channel
     assert transport._host == "squid.clam.whelk:443"
@@ -1458,7 +1623,9 @@ def test_parse_common_billing_account_path():
 
 def test_common_folder_path():
     folder = "whelk"
-    expected = "folders/{folder}".format(folder=folder,)
+    expected = "folders/{folder}".format(
+        folder=folder,
+    )
     actual = ImageVersionsClient.common_folder_path(folder)
     assert expected == actual
 
@@ -1476,7 +1643,9 @@ def test_parse_common_folder_path():
 
 def test_common_organization_path():
     organization = "oyster"
-    expected = "organizations/{organization}".format(organization=organization,)
+    expected = "organizations/{organization}".format(
+        organization=organization,
+    )
     actual = ImageVersionsClient.common_organization_path(organization)
     assert expected == actual
 
@@ -1494,7 +1663,9 @@ def test_parse_common_organization_path():
 
 def test_common_project_path():
     project = "cuttlefish"
-    expected = "projects/{project}".format(project=project,)
+    expected = "projects/{project}".format(
+        project=project,
+    )
     actual = ImageVersionsClient.common_project_path(project)
     assert expected == actual
 
@@ -1514,7 +1685,8 @@ def test_common_location_path():
     project = "winkle"
     location = "nautilus"
     expected = "projects/{project}/locations/{location}".format(
-        project=project, location=location,
+        project=project,
+        location=location,
     )
     actual = ImageVersionsClient.common_location_path(project, location)
     assert expected == actual
@@ -1539,7 +1711,8 @@ def test_client_with_default_client_info():
         transports.ImageVersionsTransport, "_prep_wrapped_messages"
     ) as prep:
         client = ImageVersionsClient(
-            credentials=ga_credentials.AnonymousCredentials(), client_info=client_info,
+            credentials=ga_credentials.AnonymousCredentials(),
+            client_info=client_info,
         )
         prep.assert_called_once_with(client_info)
 
@@ -1548,7 +1721,8 @@ def test_client_with_default_client_info():
     ) as prep:
         transport_class = ImageVersionsClient.get_transport_class()
         transport = transport_class(
-            credentials=ga_credentials.AnonymousCredentials(), client_info=client_info,
+            credentials=ga_credentials.AnonymousCredentials(),
+            client_info=client_info,
         )
         prep.assert_called_once_with(client_info)
 
@@ -1556,7 +1730,8 @@ def test_client_with_default_client_info():
 @pytest.mark.asyncio
 async def test_transport_close_async():
     client = ImageVersionsAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc_asyncio",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc_asyncio",
     )
     with mock.patch.object(
         type(getattr(client.transport, "grpc_channel")), "close"
@@ -1626,4 +1801,5 @@ def test_api_key_credentials(client_class, transport_class):
                 quota_project_id=None,
                 client_info=transports.base.DEFAULT_CLIENT_INFO,
                 always_use_jwt_access=True,
+                api_audience=None,
             )
